#ifdef NA_CODES
#include <avr/io.h>             // this contains all the IO port definitions
#include <avr/pgmspace.h>       // definitions or keeping constants in program memory
#include "main.h"

// table of POWER codes

#define freq_to_timerval(x) ((F_CPU / x - 1 )/ 2)

  
//#define AMPLIVISION_CODE 1


// Code 000 -- Sony, Baur, Neckermann, Otto Versand, Palladium, Quelle, SEI, Sinudyne, Sonolor, Universum
const uint16_t sonyTimes[] PROGMEM = {
	60,  60,
	120, 60,
	240, 60,
	60,  2759,
	60,  0,
	60,  2636,
	60,  2819,
};

const struct IrCode sonyCode PROGMEM = {
	freq_to_timerval(40000),
	sonyTimes,
	{
		0x21,
		0x01,
		0x01,
		0x00,
		0x10,
		0x00,
		0x32,
		0x10,
		0x10,
		0x10,
		0x01,
		0x00,
		0x04,
	}
};

// Code 001 - Proscan, RCA, Curtis Mathes, Dimensia, GE, JC Penney, LXI, Radio Shack/Realistic, Sears, Wards
const uint16_t rcaTimes[] PROGMEM = {
	52, 102,
	52, 205,
	411, 410,
	52, 821,
	52, 0,  //RCA end sequence
	51, 0,	//thompson end sequence
};

const struct IrCode rcaCode PROGMEM = {
	freq_to_timerval(55600),
	rcaTimes,
	{
		0x21,
		0x11,
		0x10,
		0x01,
		0x01,
		0x01,
		0x00,
		0x00,
		0x01,
		0x10,
		0x10,
		0x10,
		0x13,
		0x21,
		0x11,
		0x10,
		0x01,
		0x01,
		0x01,
		0x00,
		0x00,
		0x01,
		0x10,
		0x10,
		0x10,
		0x14,
	}
};

// Code 002 -- Panasonic
const uint16_t panasonicTimes[] PROGMEM = {
	44, 45,
	44, 135,
	358, 180,
	44, 7720,
	44, 0,
};

const struct IrCode panasonicCode PROGMEM = {
	freq_to_timerval(36130),
	panasonicTimes,
	{
		0x20,
		0x10,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x10,
		0x01,
		0x01,
		0x11,
		0x10,
		0x13,
		0x20,
		0x10,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x10,
		0x01,
		0x01,
		0x11,
		0x10,
		0x14,
	}
};

// Code 003 -- Sharp
const uint16_t sharpTimes[] PROGMEM = {
	29, 81,
	29, 189,
	29, 4670,
	29, 0,
};

const struct IrCode sharpCode PROGMEM = {
	freq_to_timerval(37470),
	sharpTimes,
	{
		0x10,
		0x00,
		0x00,
		0x11,
		0x01,
		0x00,
		0x01,
		0x02,
		0x10,
		0x00,
		0x01,
		0x00,
		0x10,
		0x11,
		0x10,
		0x12,
		0x10,
		0x00,
		0x00,
		0x11,
		0x01,
		0x00,
		0x01,
		0x02,
		0x10,
		0x00,
		0x01,
		0x00,
		0x10,
		0x11,
		0x10,
		0x13,
	}
};

// Code 004 -- Toshiba, Apex
const uint16_t toshibaTimes[] PROGMEM = {
	58, 57,
	58, 173,
	926, 230,
	924, 464,
	58, 4054,
	58, 9880,
	58, 0,
};

const struct IrCode toshibaCode PROGMEM = {
	freq_to_timerval(37470),
	toshibaTimes,
	{
		0x30,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x11,
		0x10,
		0x10,
		0x10,
		0x01,
		0x00,
		0x01,
		0x01,
		0x10,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 005 -- Philips, Grundig, Pye
const uint16_t philipsTimes[] PROGMEM = {
	89,  89,
	178, 89,
	89,  178,
	89,  9216,
	89,  0,
	178, 9216,
	178, 0
};

const struct IrCode philipsCode PROGMEM = {
	freq_to_timerval(36000),
	philipsTimes,
	{
		0x01,
		0x00,
		0x00,
		0x00,
		0x20,
		0x13,
		0x01,
		0x00,
		0x00,
		0x00,
		0x20,
		0x14,
	}
};

// Code 006 -- Samsung
const uint16_t samsungTimes[] PROGMEM = {
	53, 62,
	53, 175,
	464, 476,
	53, 4661,
	53, 0,
};

const struct IrCode samsungCode PROGMEM = {
	freq_to_timerval(37470),
	samsungTimes,
	{
		0x21,
		0x11,
		0x00,
		0x00,
		0x01,
		0x11,
		0x00,
		0x00,
		0x00,
		0x10,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x11,
		0x13,
		0x21,
		0x11,
		0x00,
		0x00,
		0x01,
		0x11,
		0x00,
		0x00,
		0x00,
		0x10,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x11,
		0x14,
	}
};

// Code 007 -- Zenith
const uint16_t zenithTimes[] PROGMEM = {
	52, 49,
	52, 419,
	52, 522,
	52, 12433,
	52, 0,
	52, 12922,
	51, 10746,
};

const struct IrCode zenithCode PROGMEM = {
	freq_to_timerval(40300),
	zenithTimes,
	{
		0x01,
		0x20,
		0x10,
		0x12,
		0x01,
		0x20,
		0x12,
		0x20,
		0x30,
		0x12,
		0x01,
		0x01,
		0x20,
		0x12,
		0x01,
		0x22,
		0x04,
	}
};

// Code 008 --Pioneer, Sansui, Toshiba
const uint16_t pioneerTimes[] PROGMEM = {
	59, 59,
	59, 173,
	926, 461,
	59, 4117,
	59, 0,
};

const struct IrCode pioneerCode PROGMEM = {
	freq_to_timerval(37470),
	pioneerTimes,
	{
		0x21,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x10,
		0x00,
		0x10,
		0x10,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x10,
		0x13,
		0x21,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x10,
		0x00,
		0x10,
		0x10,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x10,
		0x14,
	}
};

// Code 009 -- Sylvania
const uint16_t viewsonic3Times[] PROGMEM = {
	56, 56,
	56, 174,
	926, 230,
	924, 461,
	56, 4055,
	56, 9855,
	56, 0,
};

const struct IrCode sylvaniaCode PROGMEM = {
	freq_to_timerval(37430),
	viewsonic3Times,
	{
		0x31,
		0x11,
		0x00,
		0x00,
		0x10,
		0x10,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x11,
		0x11,
		0x11,
		0x11,
		0x00,
		0x04,
		0x25,
		0x26,
	}
};

// Code 010 -- JVC
const uint16_t jvcTimes[] PROGMEM = {
	53, 55,
	53, 161,
	865, 429,
	53, 2347,
	53, 0,
};

const struct IrCode jvcCode PROGMEM = {
	freq_to_timerval(37470),
	jvcTimes,
	{
		0x21,
		0x10,
		0x00,
		0x00,
		0x01,
		0x11,
		0x01,
		0x00,
		0x03,
		0x11,
		0x00,
		0x00,
		0x00,
		0x11,
		0x10,
		0x10,
		0x00,
		0x31,
		0x10,
		0x00,
		0x00,
		0x01,
		0x11,
		0x01,
		0x00,
		0x04,
	}
};

// Code 011 -- Hitachi
const uint16_t hitachiTimes[] PROGMEM = {
	58, 55,
	58, 175,
	910, 229,
	909, 452,
	58, 4146,
	58, 9597,
	56, 0,
};

const struct IrCode hitachiCode PROGMEM = {
	freq_to_timerval(37470),
	hitachiTimes,
	{
		0x30,
		0x00,
		0x01,
		0x01,
		0x01,
		0x11,
		0x10,
		0x10,
		0x11,
		0x11,
		0x01,
		0x00,
		0x00,
		0x00,
		0x10,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 012 -- Sampo
const uint16_t sampoTimes[] PROGMEM = {
	85, 87,
	85, 260,
	342, 344,
	85, 3366,
	85, 0,
};

const struct IrCode sampoCode PROGMEM = {
	freq_to_timerval(37470),
	sampoTimes,
	{
		0x21,
		0x01,
		0x10,
		0x10,
		0x11,
		0x00,
		0x00,
		0x10,
		0x10,
		0x01,
		0x00,
		0x11,
		0x13,
		0x21,
		0x01,
		0x10,
		0x10,
		0x11,
		0x00,
		0x00,
		0x10,
		0x10,
		0x01,
		0x00,
		0x11,
		0x14,
	}
};

// Code 013 -- Hisense
const uint16_t hisenseTimes[] PROGMEM = {
	56, 55,
	56, 170,
	920, 458,
	56, 2364,
	56, 9620,
	56, 0,
};

const struct IrCode hisenseCode PROGMEM = {
	freq_to_timerval(37520),
	hisenseTimes,
	{
		0x20,
		0x01,
		0x11,
		0x00,
		0x01,
		0x00,
		0x00,
		0x11,
		0x00,
		0x01,
		0x11,
		0x01,
		0x11,
		0x10,
		0x10,
		0x01,
		0x00,
		0x01,
		0x01,
		0x10,
		0x11,
		0x13,
		0x24,
		0x25,
	}
};

// Code 014 -- Viewsonic, Acer

const struct IrCode viewsonicCode PROGMEM = {
	freq_to_timerval(37470),
	toshibaTimes,
	{
		0x30,
		0x00,
		0x00,
		0x11,
		0x01,
		0x11,
		0x11,
		0x00,
		0x11,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 015 -- Bush, NET-TV

const struct IrCode bushCode PROGMEM = {
	freq_to_timerval(37470),
	toshibaTimes,
	{
		0x30,
		0x10,
		0x00,
		0x01,
		0x01,
		0x01,
		0x11,
		0x10,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x11,
		0x11,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 016 -- AOC, Daewoo, Goldstar, JC Penney, LG, Memorex, MGA, 
// Mistubishi, MTC, NEC, Philco, Portland, RCA, Samsung, 
// Teknika, Vidtech, Wards, Yamaha
const uint16_t aocTimes[] PROGMEM = {
	30, 91,
	30, 216,
	30, 2573,
	30, 0,
};

const struct IrCode aocCode PROGMEM = {
	freq_to_timerval(33600),
	aocTimes,
	{
		0x11,
		0x10,
		0x00,
		0x10,
		0x01,
		0x00,
		0x00,
		0x00,
		0x21,
		0x11,
		0x00,
		0x01,
		0x00,
		0x10,
		0x00,
		0x00,
		0x03,
	}
};

// Code 017 -- Bell & Howell, Curtis Mathes, Emerson, Fisher, LXI, Memorex, 
// Radio Shack, Realistic, Sanyo, Sears, Toshiba
const uint16_t bellTimes[] PROGMEM = {
	59, 57,
	59, 178,
	924, 231,
	924, 459,
	59, 4260,
	59, 9753,
	59, 0,
	59, 9752, 
};

const struct IrCode bellCode PROGMEM = {
	freq_to_timerval(38970),
	bellTimes,
	{
		0x30,
		0x00,
		0x11,
		0x10,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x10,
		0x01,
		0x00,
		0x01,
		0x01,
		0x10,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 018 -- Pioneer, Hitachi
const uint16_t pioneer2Times[] PROGMEM = {
	53, 55,
	53, 164,
	873, 440,
	53, 2633,
	53, 0,
};

const struct IrCode pioneer2Code PROGMEM = {
	freq_to_timerval(37470),
	pioneer2Times,
	{
		0x20,
		0x10,
		0x10,
		0x10,
		0x11,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x13,
		0x20,
		0x10,
		0x10,
		0x10,
		0x11,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x13,
		0x20,
		0x10,
		0x10,
		0x10,
		0x11,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x00,
		0x14,
	}
};

// Code 019 -- Fujitsu
const uint16_t fujitsuTimes[] PROGMEM = {
	43, 42,
	43, 126,
	336, 166,
	43, 4723,
	43, 0,
};

const struct IrCode fujitsuCode PROGMEM = {
	freq_to_timerval(37470),
	fujitsuTimes,
	{
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x00,
		0x00,
		0x03,
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x00,
		0x00,
		0x04,
	}
};

// Code 020 - Gold Star, JC Penney, LXI, Marantz, Memorex, Proton, Pulsar, 
// Toshiba, Wards
const uint16_t goldstarTimes[] PROGMEM = {
	63, 55,
	63, 166,
	926, 234,
	924, 472,
	63, 4207,
	63, 9957,
	62, 0,
};

const struct IrCode goldstarCode PROGMEM = {
	freq_to_timerval(37470),
	goldstarTimes,
	{
		0x30,
		0x01,
		0x00,
		0x00,
		0x01,
		0x10,
		0x11,
		0x11,
		0x10,
		0x00,
		0x10,
		0x00,
		0x01,
		0x11,
		0x01,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 021 - Daewoo, Emerson, Hitachi, RCA, White Westinghouse, Zenith
const uint16_t daewooTimes[] PROGMEM = {
	51, 52,
	51, 163,
	51, 409,
	822, 409,
	51, 2397,
	51, 0,
};

const struct IrCode daewooCode PROGMEM = {
	freq_to_timerval(37470),
	daewooTimes,
	{
		0x30,
		0x01,
		0x01,
		0x00,
		0x02,
		0x10,
		0x10,
		0x10,
		0x00,
		0x43,
		0x00,
		0x10,
		0x10,
		0x00,
		0x21,
		0x01,
		0x01,
		0x00,
		0x05,
	}
};

// Code 022 - NEC
const uint16_t NECTimes[] PROGMEM = {
	56, 61,
	56, 179,
	921, 230,
	918, 460,
	56, 4581,
	56, 9705,
	56, 0,
};

const struct IrCode NECCode PROGMEM = {
	freq_to_timerval(37470),
	NECTimes,
	{
		0x30,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x11,
		0x11,
		0x10,
		0x04,
		0x25,
		0x26,
	}
};

// Code 023 - Admiral, Bell & Howell, Logik, Majestic, Memorex, 
// Montgomery Ward, Signature, Teknika, Wards, Zenith
const struct IrCode admiralCode PROGMEM = {
	freq_to_timerval(40300),
	zenithTimes,
	{
		0x22,
		0x01,
		0x01,
		0x20,
		0x12,
		0x01,
		0x22,
		0x01,
		0x01,
		0x20,
		0x16,
		0x22,
		0x01,
		0x01,
		0x20,
		0x12,
		0x01,
		0x22,
		0x01,
		0x01,
		0x20,
		0x14,
	}
};

// Code 024 - Sony
const struct IrCode sony2Code PROGMEM = {
	freq_to_timerval(40000),
	sonyTimes,
	{
		0x21,
		0x11,
		0x10,
		0x10,
		0x10,
		0x00,
		0x52,
		0x11,
		0x11,
		0x01,
		0x01,
		0x00,
		0x04,
	}
};

// Code 025 - Viewsonic, Magnavox, NET-TV, Electrograph, Gateway, Maxent, 
// NetTV, Sampo
const uint16_t viewsonic2Times[] PROGMEM = {
	88, 91,
	88, 270,
	358, 358,
	88, 3562,
	88, 0,
};

const struct IrCode viewsonic2Code PROGMEM = {
	freq_to_timerval(37470),
	viewsonic2Times,
	{
		0x21,
		0x11,
		0x11,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x11,
		0x11,
		0x13,
		0x21,
		0x11,
		0x11,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x11,
		0x11,
		0x14,
	}
};

// Code 026 - Zenith
const struct IrCode zenith2Code PROGMEM = {
	freq_to_timerval(40300),
	zenithTimes,
	{
		0x01,
		0x20,
		0x10,
		0x12,
		0x20,
		0x12,
		0x01,
		0x20,
		0x50,
		0x12,
		0x01,
		0x01,
		0x22,
		0x01,
		0x20,
		0x12,
		0x04,
	}
};

// Code 027 - Thompson

const struct IrCode thompsonCode PROGMEM = {
	freq_to_timerval(55600),
	rcaTimes,
	{
		0x20,
		0x11,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x10,
		0x10,
		0x13,
		0x20,
		0x11,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x10,
		0x10,
		0x15,
	}
};

// Code 028  - Brillian, Sears
const uint16_t brillianTimes[] PROGMEM = {
	123, 123,
	123, 277,
	267, 277,
	123, 4876,
	123, 0,
};

const struct IrCode brillianCode PROGMEM = {
	freq_to_timerval(37430),
	brillianTimes,
	{
		0x20,
		0x10,
		0x10,
		0x11,
		0x01,
		0x10,
		0x00,
		0x10,
		0x13,
		0x20,
		0x10,
		0x10,
		0x11,
		0x01,
		0x10,
		0x00,
		0x10,
		0x14,
	}
};

// Code 029 - Magnavox
const struct IrCode magnavoxCode PROGMEM = {
	freq_to_timerval(36000),
	philipsTimes,
	{
		0x01,
		0x00,
		0x00,
		0x21,
		0x20,
		0x50,
		0x10,
		0x00,
		0x02,
		0x12,
		0x06,
	}
};

// Code 030 - Viewsonic

const struct IrCode viewsonic3Code PROGMEM = {
	freq_to_timerval(37470),
	viewsonic3Times,
	{
		0x30,
		0x00,
		0x01,
		0x01,
		0x01,
		0x01,
		0x10,
		0x10,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x11,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 031 - Crown, Infinity, JBL, Loewe, LXI, Magnavox, Marantz, 
// Panaxonic, Philco, Philips, Sylvania, Wards
const struct IrCode crownCode PROGMEM = {
	freq_to_timerval(34800),
	philipsTimes,
	{
		0x00,
		0x10,
		0x00,
		0x00,
		0x20,
		0x13,
		0x00,
		0x10,
		0x00,
		0x00,
		0x20,
		0x14,
	}
};

// Code 032 - Hitachi
const struct IrCode hitachi2Code PROGMEM = {
	freq_to_timerval(37470),
	viewsonic3Times,
	{
		0x30,
		0x00,
		0x01,
		0x01,
		0x01,
		0x01,
		0x10,
		0x10,
		0x10,
		0x10,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 033 - Fujitsu
const uint16_t fujitsu2Times[] PROGMEM = {
	43, 43,
	43, 124,
	346, 158,
	43, 5438,
	43, 0,
};

const struct IrCode fujitsu2Code PROGMEM = {
	freq_to_timerval(37470),
	fujitsu2Times,
	{
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x10,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x03,
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x10,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x04,
	}
};

// Code 034 - Hitachi

const struct IrCode hitachi3Code PROGMEM = {
	freq_to_timerval(37470),
	toshibaTimes,
	{
		0x30,
		0x00,
		0x01,
		0x01,
		0x01,
		0x11,
		0x10,
		0x10,
		0x11,
		0x11,
		0x11,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x14,
		0x25,
		0x26,
	}
};

// Code 035 - NEC

const struct IrCode NEC2Code PROGMEM = {
	freq_to_timerval(37470),
	toshibaTimes,
	{
		0x30,
		0x00,
		0x11,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x10,
		0x00,
		0x10,
		0x00,
		0x01,
		0x11,
		0x01,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 036 - Hitachi
const uint16_t hitachi4Times[] PROGMEM = {
	101, 94,
	101, 293,
	101, 3522,
	101, 0,
};

const struct IrCode hitachi4Code PROGMEM = {
	freq_to_timerval(40580),
	hitachi4Times,
	{
		0x00,
		0x01,
		0x01,
		0x01,
		0x00,
		0x20,
		0x00,
		0x10,
		0x10,
		0x10,
		0x03,
	}
};

// Code 037 - Anam National, Electrohome, GE, Motorola, NEC, Panasonic, 
// Philco, Philips, Quasar, RCA, Tatung
const uint16_t anamTimes[] PROGMEM = {
	88, 255,
	88, 594,
	88, 0,
};

const struct IrCode anamCode PROGMEM = {
	freq_to_timerval(36090),
	anamTimes,
	{
		0x10,
		0x00,
		0x10,
		0x11,
		0x10,
		0x20
	}
};

// Code 038 - AOC, NEC
const uint16_t aoc2Times[] PROGMEM = {
	170, 166,
	530, 167,
	42, 269,
	42, 0,
};

const struct IrCode aoc2Code PROGMEM = {
	freq_to_timerval(40580),
	aoc2Times,
	{
		0x12,
		0x22,
		0x02,
		0x00,
		0x22,
		0x30
	}
};

// Code 039 - Candle, Citizen, JC Penney, Magnavox, Philco, Philips, 
// Simpson, Soundesign, Sylvania, Teknika
const uint16_t candleTimes[] PROGMEM = {
	59, 57,
	59, 178,
	924, 231,
	924, 459,
	59, 4262,
	59, 9758,
	59, 0,
};

const struct IrCode candleCode PROGMEM = {
	freq_to_timerval(38970),
	candleTimes,
	{
		0x31,
		0x01,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x11,
		0x10,
		0x10,
		0x01,
		0x00,
		0x01,
		0x01,
		0x10,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 040 - Contec/Cony, Emerson, Goldstar, Hitachi, JVC, Philco,
// Philips, Proton, Radio Shack/Realistic, Samsung, Scott,
// Sharp, Teknika
const uint16_t contecTimes[] PROGMEM = {
	118, 103,
	118, 205,
	708, 2778,
	708, 0,
};

const struct IrCode contecCode PROGMEM = {
	freq_to_timerval(54070),
	contecTimes,
	{
		0x02,
		0x03,
	}
};

// Code 041 - Contec/Cony, Hitachi, JC Penney, JVC, Sears, Teknika

const struct IrCode contec2Code PROGMEM = {
	freq_to_timerval(38970),
	contecTimes,
	{
		0x00,
		0x12,
		0x00,
		0x13,
	}
};

// Code 042 - Sony
const struct IrCode sony3Code PROGMEM = {
	freq_to_timerval(40000),
	sonyTimes,
	{
		0x21,
		0x01,
		0x01,
		0x00,
		0x10,
		0x00,
		0x62,
		0x10,
		0x10,
		0x10,
		0x01,
		0x00,
		0x04,
	}
};

// Code 043 - Alleron, Emerson, Fujitsu, Funai, Grunpy, Scott, Sears, 
// Soundesign, Teknika, Wards
const uint16_t alleronTimes[] PROGMEM = {
	56, 66,
	56, 173,
	924, 231,
	924, 431,
	56, 4208,
	56, 8899,
	56, 0,
};

const struct IrCode alleronCode PROGMEM = {
	freq_to_timerval(38970),
	alleronTimes,
	{
		0x31,
		0x10,
		0x00,
		0x00,
		0x10,
		0x10,
		0x11,
		0x11,
		0x00,
		0x00,
		0x10,
		0x00,
		0x01,
		0x11,
		0x01,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 044 - Contec/Cony, Hitachi, JVC, Sears, Teknika
const uint16_t contec3Times[] PROGMEM = {
	136, 45,
	46, 123,
	46, 3583,
	46, 0,
};

const struct IrCode contec3Code PROGMEM = {
	freq_to_timerval(39010),
	contec3Times,
	{
		0x11,
		0x11,
		0x10,
		0x11,
		0x11,
		0x12,
		0x11,
		0x11,
		0x10,
		0x11,
		0x11,
		0x13,
	}
};

// Code 045 - Curtis Mathes, Samsung
const uint16_t curtisTimes[] PROGMEM = {
	54, 51,
	54, 163,
	908, 224,
	444, 446,
	54, 4204,
	54, 9767,
	54, 0,
};

const struct IrCode curtisCode PROGMEM = {
	freq_to_timerval(38970),
	curtisTimes,
	{
		0x31,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x11,
		0x11,
		0x10,
		0x10,
		0x00,
		0x00,
		0x01,
		0x01,
		0x11,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 046 - Aiko, Citizen, Daewoo, Nikko, NTC, Portland, Teknika
const uint16_t aikoTimes[] PROGMEM = {
	61, 53,
	61, 170,
	470, 459,
	61, 4612,
	61, 9937,
	61, 0,
};

const struct IrCode aikoCode PROGMEM = {
	freq_to_timerval(37470),
	aikoTimes,
	{
		0x20,
		0x11,
		0x00,
		0x00,
		0x00,
		0x11,
		0x00,
		0x00,
		0x01,
		0x11,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x13,
		0x21,
		0x42,
		0x15,
	}
};

// Code 047 - Daewoo
const uint16_t daewoo2Times[] PROGMEM = {
	56, 52,
	108, 52,
	56, 106,
	56, 282,
	56, 2592,
	56, 13150,
	56, 0,
};

const struct IrCode daewoo2Code PROGMEM = {
	freq_to_timerval(28670),
	daewoo2Times,
	{
		0x32,
		0x10,
		0x00,
		0x43,
		0x20,
		0x00,
		0x00,
		0x53,
		0x20,
		0x00,
		0x00,
		0x60
	}
};

// Code 048 - Electrohome, GE, JC Penney, MGA, Mitsubishi

const struct IrCode electrohomeCode PROGMEM = {
	freq_to_timerval(38970),
	bellTimes,
	{
		0x30,
		0x00,
		0x01,
		0x00,
		0x01,
		0x11,
		0x10,
		0x11,
		0x11,
		0x11,
		0x10,
		0x11,
		0x10,
		0x00,
		0x01,
		0x00,
		0x04,
		0x27,
		0x26,
	}
};

// Code 049 - Emerson, Sharp

const struct IrCode emersonCode PROGMEM = {
	freq_to_timerval(38970),
	curtisTimes,
	{
		0x30,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x11,
		0x11,
		0x11,
		0x11,
		0x10,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// Code 050 - Fisher, MGA, Mitsubishi, Sears
const uint16_t fisherTimes[] PROGMEM = {
	282, 876,
	282, 2038,
	282, 0,
};

const struct IrCode fisherCode PROGMEM = {
	freq_to_timerval(44330),
	fisherTimes,
	{
		0x01,
		0x10,
		0x01,
		0x01,
		0x10,
		0x20
	}
};

#ifdef AMPLIVISION_CODE
// Code 051 - Amplivision, Atlantic, Clatronic, Condor, Desnet, Formenti, 
// Hanseatic, Korting, Manesth, NEC, Orion, Otto Versand, 
// Pathe Cinema, Perdio, Phoenix, Sogera, Soundwave, Standard, 
// Technema, Telemeister, Televideon, Tensai, Tenson, Uher,
// Videotechnic, Vision, Watson, Weltblick, White Westinghouse
const uint16_t amplivisionTimes[] PROGMEM = {
	3, 19,
	14, 19,
	71, 19,
	3, 29,
	48, 29,
	3, 13072,
	3, 0,
};

const struct IrCode amplivisionCode PROGMEM = {
	freq_to_timerval(8860),
	amplivisionTimes,
	{
		0x32,
		0x45,
		0x31,
		0x00,
		0x01,
		0x46,
	}
};
#endif

// Code 052 - GE, JC Penney, JVC, Midland, Panasonic, Prism, Quasar, 
// Techics, Techwood
const uint16_t geTimes[] PROGMEM = {
	83, 89,
	83, 260,
	369, 339,
	83, 3849,
	83, 0,
};

const struct IrCode geCode PROGMEM = {
	freq_to_timerval(54160),
	geTimes,
	{
		0x20,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x11,
		0x11,
		0x11,
		0x11,
		0x03,
		0x20,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x11,
		0x11,
		0x11,
		0x11,
		0x11,
		0x04,
	}
};

// Code 053 - JVC

const struct IrCode jvc2Code PROGMEM = {
	freq_to_timerval(38970),
	bellTimes,
	{
		0x30,
		0x01,
		0x00,
		0x01,
		0x11,
		0x10,
		0x11,
		0x10,
		0x00,
		0x00,
		0x11,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x14,
		0x27,
		0x26,
	}
};

// Code 054 - JVC
const struct IrCode jvc3Code PROGMEM = {
	freq_to_timerval(38970),
	bellTimes,
	{
		0x31,
		0x11,
		0x01,
		0x10,
		0x00,
		0x00,
		0x10,
		0x01,
		0x10,
		0x10,
		0x01,
		0x00,
		0x01,
		0x01,
		0x10,
		0x11,
		0x14,
		0x27,
		0x26,
	}
};

// Code 055 - Kloss Novabeam, Magnavox, Philco, Philips, Sylvania, Wards
const uint16_t klossTimes[] PROGMEM = {
	53, 237,
	53, 524,
	53, 812,
	53, 2959,
	53, 0,
};

const struct IrCode klossCode PROGMEM = {
	freq_to_timerval(54070),
	klossTimes,
	{
		0x02,
		0x02,
		0x02,
		0x01,
		0x10,
		0x00,
		0x01,
		0x30,
		0x20,
		0x20,
		0x20,
		0x11,
		0x00,
		0x00,
		0x14,
	}
};

#ifdef AMPLIVISION_CODE
const uint8_t num_codes = 56;
#else
const uint8_t num_codes = 55;
#endif

#ifdef AMPLIVISION_CODE
const struct IrCode *powerCodes[56] PROGMEM = {
#else
const struct IrCode *powerCodes[56] PROGMEM = {
#endif
	&sonyCode,
	&rcaCode,
	&panasonicCode,
	&sharpCode,
	&toshibaCode,
	&philipsCode,
	&samsungCode,
	&zenithCode,
	&pioneerCode,
	&sylvaniaCode,
	&jvcCode,
	&hitachiCode,
	&sampoCode,
	&hisenseCode,
	&viewsonicCode,
	&bushCode,
	&aocCode,
	&bellCode,
	&pioneer2Code,
	&fujitsuCode,
	&goldstarCode,
	&daewooCode,
	&NECCode,
	&admiralCode,
	&sony2Code,
	&viewsonic2Code,
	&zenith2Code,
	&thompsonCode,
	&brillianCode,
	&magnavoxCode,
	&viewsonic3Code,
	&crownCode,
	&hitachi2Code,
	&fujitsu2Code,
	&hitachi3Code,
	&NEC2Code,
	&hitachi4Code,
	&anamCode,
	&aoc2Code,
	&candleCode,
	&contecCode,
	&contec2Code,
	&sony3Code,
	&alleronCode,
	&contec3Code,
	&curtisCode,
	&aikoCode,
	&daewoo2Code,
	&electrohomeCode,
	&emersonCode,
	&fisherCode,
#ifdef AMPLIVISION_CODE
	&amplivisionCode,
#endif
	&geCode,
	&jvc2Code,
	&jvc3Code,
	&klossCode,
};

//bytes_in:  9024
//bytes_out: 2543
#endif
