

// IR Code compression
// 2007-10-31
// Kevin Timmerman
//
// Modified by CaitSith2.  Added code tolerance checking.
// Added the European codelist as recorded from a European TVBgone
// by Kevin Timmerman.
// 2007-11-20
// Damien Good


struct codeElement {
  unsigned int onTime;   // duration of "On" time
  unsigned int offTime;  // duration of "Off" time
};

struct powercode {
  unsigned int timer_val; // not the actual frequency, but the timer value to generate the frequency
  struct codeElement codes[];  // flexible number of on/off codes
};

#define freq_to_timerval(x) (x)
#define PROGMEM
#define PGM_P struct powercode
#define uint8_t unsigned int

#define ALL_CODES
#define NA_CODES

#ifdef NA_CODES
	#include "NAcodes.c"
#else
	#include "EUcodes.c"
#endif
#include "stdio.h"
#include "stdlib.h"

int compare_ce(struct codeElement *ce1, struct codeElement *ce2, unsigned int tolerance)
{
	struct codeElement diff_ce;
	diff_ce.onTime = 0;
	diff_ce.offTime = 0;
	if (ce1[0].onTime < ce2[0].onTime)
	{
		diff_ce.onTime = ce2[0].onTime - ce1[0].onTime;
	}
	else if (ce1[0].onTime > ce2[0].onTime)
	{
		diff_ce.onTime = ce1[0].onTime - ce2[0].onTime;
	}
	if (ce1[0].offTime < ce2[0].offTime)
	{
		diff_ce.offTime = ce2[0].offTime - ce1[0].offTime;
	}
	else if (ce1[0].offTime > ce2[0].offTime)
	{
		diff_ce.offTime = ce1[0].offTime - ce2[0].offTime;
	}
	if((diff_ce.onTime < tolerance) && (diff_ce.offTime < tolerance))
		return 1;
	return 0;
}

int code_skip[200];
int level_two[200];		//If a code has 8 or less code elements, then A simple 1 byte RL encoding is possible, which
						//breaks even at 2 repeats of a code element.
						//The format would be xyyyzzzz where x indicates whether or not RL is in use.
						//yyy indicates the code element to use, from 0-7,  and zzzz indicates number of repeats
						//from 3 to 19. (2 breaks even.)

struct codeElement celist[16][200];
int celisttype[200];
int celistpointer=0;
int ceduplicate[200];

int compare_ce_list(struct codeElement *ce1, int ce_size, int ce_num, unsigned int tolerance)
{
	int i,j;
	for(i=0;i<celistpointer;i++)
	{
		for(j=0;j<ce_size;j++)
		{
			if(!compare_ce(&ce1[j],&celist[j][i],tolerance))
				break;
		}
		if(j==ce_size)
		{
			celisttype[ce_num]=celisttype[i];
			return i;
		}
	}
	for(i=0;i<ce_size;i++)
	{
		celist[i][celistpointer].offTime = ce1[i].offTime;
		celist[i][celistpointer].onTime = ce1[i].onTime;
	}
	celistpointer++;
	celisttype[ce_num] = ce_num;
	return -1;
}

int bitsleft_w = 8;
unsigned char bits_w=0;

int write_bits(unsigned long data, int count)
{
	int i;
	int bytes_written=0;
	for(i=0;i<count;i++)
	{
		bitsleft_w--;
		bits_w |= (((data >> (count-1-i)) & 1) << bitsleft_w);
		if(bitsleft_w==0)
		{
			printf("\t\t0x%.2X,\n",bits_w);
			bitsleft_w = 8;
			bits_w = 0;
			bytes_written++;
		}
	}
	return bytes_written;
}

int flush_bits()
{
	int i;
	int bytes_written=0;
	i=8-bitsleft_w;
	if(i>0)
	{
		printf("\t\t0x%.2X,\n",bits_w);
		bytes_written++;
	}
	bitsleft_w = 8;
	bits_w = 0;
	return bytes_written;
}




main()
{
	struct powercode const *pc;
	struct codeElement ce[16], tce;
	unsigned int n, i, nn, ns, nce, tolerance;
	unsigned int bytes_in, bytes_out, bytes_in_temp;
	int com_type;

	bytes_in = bytes_out = 0;

	for(n=0; n<num_codes; ++n) {
		code_skip[n]=0;
		level_two[n]=0;
		pc=powerCodes[n];
		bytes_in+=1;
		i=0;
		nce=0;
		bytes_in_temp = 0;
		tolerance = INITIAL_TOLERANCE;
		do {
			for(nn=0; (nn<nce)&&(nn<16); ++nn)
				//if(ce[nn].onTime==pc->codes[i].onTime && ce[nn].offTime==pc->codes[i].offTime)
				if(compare_ce(&ce[nn],&pc->codes[i],tolerance))
				break;
			if(nn==16)
			{
				i=-1;
				nce=0;
				bytes_in_temp=0;
				tolerance++;
				level_two[n]=0;
				continue;
			}
			if(nn==nce) {
				level_two[n]++;
				ce[nn].onTime=pc->codes[i].onTime;
				ce[nn].offTime=pc->codes[i].offTime;
				++nce;
			}
			bytes_in_temp+=4;
		} while(pc->codes[i++].offTime);
		bytes_in+=bytes_in_temp;
		//if((nce>16)||(pc->timer_val==0))
		if(nce>16)
		{
			code_skip[n]=1;
			printf("//\n// %i\n",n);
			printf("//const uint16_t %sTimes[] PROGMEM = {\n",codeNames[n]);
			for(nn=0; nn<nce; ++nn) {
				printf("//\t%i, %i,\n",ce[nn].onTime,ce[nn].offTime);
				bytes_out+=4;
			}
			printf("//};\n\n");
			continue;
		}

		for(nn=1; nn<nce; ++nn) {
			ns=nn;
			while(ns && ce[ns].offTime &&
				((ce[ns].offTime < ce[ns-1].offTime) ||
				((ce[ns].offTime == ce[ns-1].offTime) && (ce[ns].onTime < ce[ns-1].onTime)))) {
				tce=ce[ns];
				ce[ns]=ce[ns-1];
				ce[ns-1]=tce;
				--ns;
			}
		}
		//int compare_ce_list(struct codeElement *ce1, int ce_size, int ce_num, unsigned int tolerance)
		if(compare_ce_list(ce,nce,n,tolerance)==-1)
		{
			printf("\n// %i\n",n);
			printf("const uint16_t %sTimes[] PROGMEM = {\n",codeNames[n]);
			for(nn=0; nn<nce; ++nn) {
				printf("\t%i, %i,\n",ce[nn].onTime,ce[nn].offTime);
				bytes_out+=4;
			}
			printf("};\n\n");
		}
		else
		{
			printf("//%d is a Duplicate of code %d\n",n,compare_ce_list(ce,nce,n,tolerance));
		}
		
		if(nce<=4)
		{
			com_type = 2;
		}
		else if(nce<=8)
		{
			com_type = 1;
		}
		else
		{
			com_type = 0;
		}
		//continue;

		printf("const struct IrCode %sCode PROGMEM = {\n",codeNames[n]);
		if(pc->timer_val!=0)
			printf("\tfreq_to_timerval(%i),\n",pc->timer_val);
		else
			printf("\tfreq_to_timerval(MIN_FREQ),\n");
		printf("\t%sTimes,\n",codeNames[celisttype[n]]);
		//printf("\t%d,\t//compression type\n",com_type);
		printf("\t{\n");
		bytes_out+=3;
		write_bits(com_type,2);
		if(com_type==0)
			write_bits(0,2);
		i=0;
		do {
			//printf("\t%i, %i\n",pc->codes[i].onTime,pc->codes[i].offTime);
			for(nn=0; nn<nce; ++nn) {
				if(compare_ce(&ce[nn],&pc->codes[i],tolerance)) {
					bytes_out+=write_bits(nn,4-com_type);
					break;
				}
			}
			if(nn==nce) exit(-1);
		} while(pc->codes[i++].offTime);
		bytes_out+=flush_bits();
		printf("\t}\n");
		printf("};\n");
	}
	for(n=0,nn=0;n<num_codes; ++n)
	{
		if(!code_skip[n])
			nn++;
	}
	printf("\nconst uint8_t num_codes = %i;\n",num_codes);
	printf("\nconst struct IrCode *powerCodes[%i] PROGMEM = {\n",nn);
	for(n=0; n<num_codes; ++n) {
		if(!code_skip[n])
			printf("\t&%sCode,\n",codeNames[n]);
	}
	printf("};\n");

	printf("\n//bytes_in:  %i\n",bytes_in);
	printf("//bytes_out: %i\n",bytes_out);

	
	printf("//%d of %d codes present\n",nn,num_codes);

	for(n=0,nn=0;n<num_codes; ++n)
	{
		if(level_two[n]<=8)
			nn++;
	}
	printf("//%d of %d codes can be RL compressed\n",nn,num_codes);
	return 0;
}
